      subroutine multisi(temp,pbars,blkmag,cpm,dh2o,enthalpy,entropy, &
      mwttot,rhom,wtoxan,xcomp,hwm,swm,gwm,dgdxw,dvmdt)

!      SUBROUTINE THAT CALCULATES THERMODYNAMIC PROPERTIES OF MELTS USING
!      THE METHODOLOGY OF GHIORSO & SACK (1995; CONTRIB. MIN. PET., 199:
!      197-212).  THIS SUBROUTINE IS SIMILAR TO THE SUBROUTINE MULTICOMP,
!      USED BY THE PROGRAM DECOMP2, EXCEPT THAT IT CONVERTS ITS FINAL
!      VALUES OF ENTROPY AND ENTHALPY INTO J/KG K AND J/KG, RESPECTIVELY,
!      INSTEAD OF J/MOLE K AND J/MOLE.  OTHER VALUES EXPORTED
!      (MWTTOT, VTOT, ETC) ARE IN SI UNITS AS WELL.

!      THE METHOD FIRST CALCULATES THE GIBBS FREE ENERGY OF THE FOLLOWING
!      END-MEMBER COMPONENTS OF A SILICATE MELT:

!      COMPOUND      NAME      INDEX NUMBER
!      SIO2      SILICA (AMORPHOUS)      1
!      TIO2      RUTILE      2
!      AL2O3   CORUNDUM      3
!      FE2O3   HEMATITE      4
!      FE2SIO4 FAYALITE      5
!      MG2SIO4 FORSTERITE      6
!      CASIO3  PSEUDOWOLLASTONITE      7
!      NA2SIO3 SODIUM METASILICATE      8
!      KALSIO4 KALSILITE      9
!      H2O      WATER (LIQUID)      10
!      

!      VARIABLE NAMES      (ALL VALUES ARE PER MOLE)

!      COMP      COMPRESSIBILITY OF WATER (1/MPA)
!      CPLIQ(10)      CP OF LIQUID
!      DH2O      MASS FRACTION WATER DISSOLVED IN THE TOTAL SYSTEM 
!      (MELT+XTLS+GAS)
!      DPDT      CHANGE IN PRESSURE W/TEMP FOR WATER (MPA/K)
!      DVDT0(10)      CHANGE IN SPECIFI! VOLUME WITH TEMP AT STANDARD 
!      T AND P
!      DVDT(10)      CHANGE IN SPECIFI! VOLUME WITH TEMP AT SPECIFIED 
!!      T AND P
!      DVDP0(10)      CHANGE IN SPECIFI! VOLUME WITH PRESSURE AT STANDARD 
!      T AND P
!      DVDP(10)      CHANGE IN VOLUME WITH PRESSURE AT SPECIFIED T AND P
!      D2VDTDP(10)      SECOND DERIVATIVE OF SP. VOLUME WITH T AND P
!      D2VDP2(10)      SECOND DERIVATIVE OF SP. VOLUME WITH P
!      GAPP(10)      APPARENT GIBBS FREE ENERGY OF MELT (J/MOLE)
!      GFUSION(10)      GIBBS FREE ENERGY OF THE LIQUID AT THE MELTING TEMP
!      HAPP(10)      APPARENT ENTHALPY OF MELT (J/MOLE)
!      HFUSION(10)      ENTHALPY OF LIQUID AT TFUSION (J/MOLE)
!      HWM      PARTIAL MOLAR ENTHALPY OF DISSOLVED WATER
!      LABEL(10)      LABELS OF END-MEMBER COMPONENTS
!      LABELOX(10)      LABELS OF OXIDE COMPONENTS
!      MASSOX(10)      MOLECULAR WEIGHTS OF OXIDE COMPONENTS
!      MCOMP(10)      MOLES OF END-MEMBER COMPONENTS
!      MWTCOMP(10)      MOLECULAR WEIGHT OF EACH COMPONENT (KG/MOLE)
!      MWTTOT      AVERAGE MOLECULAR WEIGHT OF MELT (FROM END-MEMBER 
!      COMPONENTS)
!      PR      STANDARD PRESSURE (1 ATM)
!      PBARS      PRESSURE (BARS)
!      R      UNIVERSAL GAS CONSTANT (8.314 J/MOLE K)
!      RHO1ATM      DENSITY AT 1 ATM, T (KG/M3)
!      SAPP(10)      APPARENT ENTROPY OF MELT
!      SFUSION(10)      THIRD-LAW ENTROPY OF LIQUID AT THE MELTING 
!      TEMPERATURE
!      SUMWXX(10)      SUM OF W(I,J)*X(J)
!      SWM      PARTIAL MOLAR ENTROPY OF DISSOLVED WATER IN MELT
!      TFUSION(10)      MELTING TEMPERATURE (K)
!      TR      STANDARD TEMPERATURE (298.15 K)
!      VO(10)      SPECIFI! VOLUME AT P=1 ATM, T=1673 K)
!      V(10)      SPECIFI! VOLUME OF EACH COMPONENT AT SPECIFIED 
!      T, P (J/BAR)
!      VTOT      SPECIFI! VOLUME OF TOTAL MELT
!      WTOXAN(9)      WEGHT PERCENT OF OXIDE COMPONENTS (ANHYDROUS)
!      WTOXIDE(10)      WEIGHT PERCENT OF OXIDE COMPONENTS (HYDROUS)


!      I USE UNITS OF TEMPERATURE (K) AND PRESSURE (BARS) TO REMAIN
!      CONSISTENT WITH OTHER THERMODYNAMI! MODELS OF MINERALS AND
!      MELTS (GHIORSO & SACK, 1995; BERMAN, 1988).

      use precis_param

      implicit none
      real(kind=ip) :: cpliq(10), dvdp(10), dvdp0(9), dvdt(10), dvdt0(9), &
             d2vdpdt(9), d2vdp2(9),dvdth2o, &
             gapp(10), gwm, happ(10),  &
             hfusion(9), hwm, massox(10),  &
             mcomp(10), mwtcomp(10), moxide(10), &
             sapp(10), sfusion(9), sumwxx(10), swm, &
             tfusion(9),      vo(9), v(10), w(10,10), wtoxan(9), &
             wtoxide(10), xcomp(10), xoxide(10)
      real(kind=ip) ::  ah2o,bh2o,blkgas,blkmag,cph2o,cpm,cvh2o,d2grobiedt2, &
             d3grobiedt3,dgdt, &
             d2gdt2,d3gdt3,dgrobiedt,dgdxw,dh2o, &
             dphipdp,dphipdt,d2phipdpdt,d2phipdp2,d2phipdt2, &
             d3phipdt3,dtmp, &
             dvmdp,dvmdt,enthalpy,entropy,gh2o,grobie,hh2o, &
             moles,mwttot, &
             pbars,phip,pr,r,rhom,sh2o,sumgibbs,sumh,sums, &
             sumw,sumwh,sumwx, &
             sumxcomp,temp,tr,v1atm,vdp, &
             vh2o,vtot
      integer icomp,icp,imin,ioxide

!      character*10 label(10), labelox(10)

      data cpliq/70.823,109.2,170.3,240.9,240.2,271.,172.4,180.2, &
         217.,0./
      data dvdp0/-1.89e-05,-2.31e-05,-2.26e-05,-2.53e-05,-2.79e-05, &
         -1.35e-05,-1.55e-05,-4.29e-05,-6.4e-05/
      data d2vdp2/3.6e-10,5.0e-10,4.0e-10,4.4e-10,14.6e-10,4.14e-10, &
         3.89e-10,8.49e-10,12.1e-10/
      data d2vdpdt/1.3e-08,0.,2.7e-08,3.1e-08,-2.3e-08,-1.3e-08, &
         -1.6e-08,-5.3e-08,-4.6e-08/
      data dvdt0/0.,7.25e-04,2.62e-04,9.09e-04,5.84e-04,5.24e-04, &
         2.92e-04,7.41e-04,7.27e-04/
!      data gfusion/-.10431E+07,-.11662E+07,-.20978E+07,-.12459E+07,
!      * -.19011E+07,-.27549E+07,-.19749E+07,-.18546E+07,
!      * -.27205E+07/
      data hfusion/-.82346E+06,-.762692E+06,-.130972E+07, &
         -.47792E+06,-.11763E+07,-.172335E+07,-.138822E+07, &
         -.13461E+07,-.176486E+07/
!      data label/'SiO2','TiO2','Al2O3','Fe2O3','Fe2SiO4','Mg2SiO4',
!      * 'CaSiO3','Na2SiO3','KAlSiO3','H2O'/
!      data labelox/'SiO2','Al2O3','Fe2O3','FeO','MgO','CaO',
!      * 'TiO2','Na2O','K2O','H2O'/
!      data mass/0.0601,0.0799,0.102,0.1597,0.2038,0.1407,
!      * 0.1162,0.1221,0.1312,.018015/
      data massox/.060084,.101961,.159691,.071846,.040304, &
         .056077,.079878,.061979,.094195,.018015/
      data mwtcomp/.060088,.079898,.101957,.159697,.203786,.14071, &
         .116167,.122067,.142169,.01802/
      data sfusion/.14842E+03,.215792E+03,.33971E+03,.40528E+03, &
         .48645E+03,.47691E+03,.322874E+03,.37362E+03,.47240E+03/
      data tfusion/1480.,1870.,2320.,1895.,1490.,2163.,1817., &
         1361.,2023./
      data vo/2.690,2.3161,3.711,4.2131,5.4201,4.9801, &
             4.347,5.5681,6.8376/
      data w/  0.0000D+00,  2.6267D+07,  -3.9120D+07,  8.1100D+06, &
             2.3661D+07,  3.4210D+06,  -8.6400D+05,  -9.9039D+07, &
             -3.3922D+07,  3.0976D+07, &
             2.6267D+07,  0.0000D+00,  -2.9450D+07,  -8.7457D+07, &
             5.2090D+06, -4.1780D+06,  -3.5373D+07,  -1.5416D+07, &
             -4.8095D+07,  8.1879D+07, &
             -3.9120D+07, -2.9450D+07,   0.0000D+00,   -1.7089D+07, &
             -3.0509D+07,  -3.2880D+07, -5.7918D+07,   -1.3079D+08, &
             -2.3859D+07,  -1.6098D+07, &
             8.1100D+06,  -8.7457D+07, -1.7089D+07,      0.0000D+00, &
             -1.7907D+08,  -7.1519D+07,  1.2077D+07,   -1.4966D+08, &
             5.7556D+07,   3.1406D+07, &
             2.3661D+07,   5.2090D+06, -3.0509D+07,   -1.7907D+08, &
             0.0000D+00,  -3.7257D+07, -1.2971D+07,   -9.0534D+07, &
             2.3649D+07,   2.8874D+07, &
             3.4210D+06,  -4.1780D+06, -3.2880D+07,   -7.1519D+07, &
             -3.7257D+07,   0.0000D+00, -3.1732D+07,   -4.1877D+07, &
             2.2323D+07,   3.5634D+07, &
             -8.6400D+05,  -3.5373D+07, -5.7918D+07,      1.2077D+07, &
             -1.2971D+07,  -3.1732D+07,  0.0000D+00,   -1.3247D+07, &
             1.7111D+07,   2.0375D+07, &
             -9.9039D+07,  -1.5416D+07, -1.3079D+08,   -1.4966D+08, &
             -9.0534D+07,  -4.1877D+07, -1.3247D+07,      0.0000D+00, &
             6.5230D+06,  -9.6938D+07, &
             -3.3922D+07,  -4.8095D+07, -2.3859D+07,      5.7556D+07, &
             2.3649D+07,   2.2323D+07,  1.7111D+07,      6.5230D+06, &
             0.0000D+00,   1.0374D+07, &
             3.0976D+07,   8.1879D+07, -1.6098D+07,      3.1406D+07, &
             2.8874D+07,   3.5634D+07,  2.0375D+07,   -9.6938D+07, &
             1.0374D+07,   0.0000D+00/


!      DEFINE CONSTANTS
      r = 8.314
      tr=298.15
      pr=1.013
      dtmp = 25.

!      CALCULATE APPARENT VALUES FOR MELT
      do 100 imin=1,9
      sapp(imin) = sfusion(imin) + cpliq(imin)*log(temp/ &
             tfusion(imin))
      happ(imin) = hfusion(imin) + cpliq(imin)*(temp-tfusion(imin))
      gapp(imin) = happ(imin) - temp*sapp(imin)

!      CALCULATE SPECIFIC VOLUME AT P=1 ATM, T=TEMP
      v1atm   = vo(imin)+dvdt0(imin)*(temp-1673.)

!      CALCULATE THERMODYNAMIC PROPERTIES AT pbars, TEMP
      vdp      = v1atm*(pbars-pr) +  &
             (dvdp0(imin) + d2vdpdt(imin)*(temp-1673.))* &
             (pbars**2/2. - pbars*pr + pr**2/2.) &
             + d2vdp2(imin)* &
             (pbars**3/6. - pbars*pr**2  &
             + pbars**2*pr - pr**3/6.)
      v(imin)      = v1atm + (dvdp0(imin)  &
             + d2vdpdt(imin)*(temp-1673.))*(pbars-pr) &
             + d2vdp2(imin)*(pbars**2/2. - pbars*pr +  &
             pr**2/2.)
      dvdt(imin) = dvdt0(imin)
      dvdp(imin) =  dvdp0(imin) + d2vdpdt(imin)*(temp-1673.) &
             + d2vdp2(imin)*(pbars-pr)
      sapp(imin) = sapp(imin) - dvdt0(imin)*(pbars-pr)
      happ(imin) = happ(imin) + vdp - temp*dvdt0(imin)*(pbars-pr)
      gapp(imin) = happ(imin) - temp*sapp(imin)

100      continue

!      DETERMINE THERMODYNAMI! PROPERTIES OF DISSOLVED WATER USING
!      HAAR ET AL. EQUATION OF STATE, FOR WATER OF THE GIVEN
!      TEMPERATURE AND AT 1 BAR PRESSURE

      call haarsi(temp,1.0_ip,cpH2O,cvH2O,gH2O,hH2O,sH2O,vH2O, &
             blkgas,dvdth2o)

!      DETERMINE THE MOLAR GIBBS FREE ENERGY OF WATER AT THE SPECIFIED
!      TEMPERATURE AND 1 BAR PRESSURE USING THE METHOD OF ROBIE.  THE 
!      EQUATIONS BELOW WERE GIVEN TO ME BY MARK GHIORSO.

      gRobie = r*temp*(2.9147*log(temp) - 9.6863d-04*temp  &
             + 6.8593d-08*temp**2      + 77.8899/sqrt(temp) &
             - 28954.8/temp - 2263.27/temp**2 - 15.8997)
      dgRobiedt = r*(2.9147*log(temp) - 9.6863d-04*temp  &
             + 6.8593d-08*temp**2      + 77.8899/sqrt(temp) &
             - 28954.8/temp - 2263.27/temp**2 - 15.8997) &
             + r*temp*(2.9147/temp - 9.6863d-04  &
             + 2.0*6.8593d-08*temp - 0.5*77.8899/temp**1.5 &
             + 28954.8/temp**2      + 2.0*2263.27/temp**3)
      d2gRobiedt2 = 2.0*r*(2.9147/temp      - 9.6863d-04  &
             + 2.0*6.8593d-08*temp - 0.5*77.8899/temp**1.5 &
             + 28954.8/temp**2      + 2.0*2263.27/temp**3) &
             + r*temp*(-2.9147/temp**2   &
             + 2.0*6.8593d-08      + 0.75*77.8899/temp**2.5 &
             - 2.0*28954.8/temp**3 - 6.0*2263.27/temp**4)
      d3gRobiedt3 = 3.0*r*(-2.9147/temp**2  &
             + 2.0*6.8593d-08      + 0.75*77.8899/temp**2.5 &
             - 2.0*28954.8/temp**3 - 6.0*2263.27/temp**4) &
             + r*temp*(2.0*2.9147/temp**3   &
             - 2.25*77.8899/temp**3.5 &
             + 6.0*28954.8/temp**4 + 24.0*2263.27/temp**5)

!      CALCULATE PHIP AND ITS DERIVATIVES USING AN EQUATION LIFTED FROM 
!      A PROGRAM BY MARK GHIORSO.

      phiP = (0.110/temp + 4.432d-05 + 1.405d-07*temp  &
             - 2.394d-11*temp**2)*pbars &
             + (7.337d-08/temp - 1.170d-08 - 9.502d-13*temp)*pbars**2 &
             + (1.876d-10/temp + 4.586d-13)*pbars**3 &
             - 1.191d-14*pbars**4/temp
      dphiPdt = (-0.110/temp**2 + 1.405d-07 - 2.0*2.394d-11*temp)* &
             pbars &
             + (-7.337d-08/temp**2 - 9.502d-13)*pbars**2 &
             - 1.876d-10*pbars**3/temp**2       &
             + 1.191d-14*pbars**4/temp**2
      d2phiPdt2 = (2.0*0.110/(temp**3) - 2.0*2.394d-11)*pbars &
             + 2.0*(7.337d-08*pbars**2 + 1.876d-10*pbars**3 &
             - 1.191d-14*pbars**4)/temp**3
      d3phiPdt3 = -6.0*(0.110*pbars + 7.337d-08*pbars**2  &
             + 1.876d-10*pbars**3 - 1.191d-14*pbars**4)/ &
             temp**4
      dphiPdp = (0.110/temp + 4.432d-05 + 1.405d-07*temp  &
             - 2.394d-11*temp**2) &
             + 2.*(7.337d-08/temp - 1.170d-08 - 9.502d-13*temp)*pbars &
             + 3.*(1.876d-10/temp + 4.586d-13)*pbars**2 &
             - 4.*1.191d-14*pbars**3/temp
      d2phiPdpdt = -0.110/temp**2 + 1.405d-07 - 2.*2.394d-11*temp &
             + 2.*(-7.337d-08/temp**2 - 9.502d-13)*pbars &
             + 3.*(-1.876d-10/temp**2)*pbars**2 &
             + 4.*1.191d-14*pbars**3/temp**2
      d2phiPdp2 =  2.*(7.337d-08/temp - 1.170d-08 - 9.502d-13*temp) &
             + 6.*(1.876d-10/temp + 4.586d-13)*pbars &
             - 12.*1.191d-14*pbars**2/temp
      v(10)      = dphiPdp*r*temp
      dvdp(10) = d2phiPdp2*r*temp
      dvdt(10) = d2phiPdpdt*r*temp + r*dphiPdp

!      COMPUTE GIBBS FREE ENERGY OF WATER IN MELT USING METHODS OF GHIORSO
!      ET AL. (1983, CONTRIB. MIN. PET., 84:107-145).  GHIORSO ET AL.
!      CALCULATE THE GIBBS FREE ENERGY AT TEMP=T, P=1 ATM USING THE
!      RELATION GAPP=(A/T + B)*RT, WHERE A AND B ARE CONSTANTS WITH VALUES
!      A=-33676.0 K**-1, AND B=18.3527 (FROM MARK GHIORSO).

!      THE GIBBS FREE ENERGY AT ELEVATED PRESSURE IS CALCULATED USING
!      A FORMULA FROM MARK GHIORSO

      ah2o = -33676.0
      bh2o = 18.3527

      gapp(10) = (ah2o/temp + bh2o + phiP)*r*temp + gh2o - grobie

      dgdt   = r*(ah2o/temp + bh2o + phiP)  &
             + r*temp*(-ah2o/temp**2 + dphiPdt)      - dgRobiedt
      d2gdt2 = 2.0*r*(-ah2o/temp**2 + dphiPdt)  &
             + r*temp*(2.0*ah2o/temp**3 + d2phiPdt2) - d2gRobiedt2
      d3gdt3 = 3.0*r*(2.0*ah2o/temp**3 + d2phiPdt2)  &
             + r*temp*(-6.0*ah2o/temp**4 + d3phiPdt3) - d3gRobiedt3

!      THE FOLLOWING FORMULAS FOR ENTROPY AND ENTHALPY OF WATER WERE TAKEN
!      FROM A PROGRAM BY MARK GHIORSO.
      sapp(10) = sh2o - dgdt
      happ(10) = gapp(10) + temp*sapp(10)
      cpliq(10) = cpH2O - temp*d2gdt2

!***************************************************************************

!      CALCULATE THERMODYNAMI! PROPERTIES OF THE MELT, AND PARTIAL
!      MOLAR PROPERTIES OF EACH COMPONENT

!***************************************************************************

      wtoxide(10) = 1.d02*dh2o

!      CALCULATE WT% OXIDES IN HYDROUS MELT
      do 55 ioxide=1,9
55      wtoxide(ioxide) = (100.-wtoxide(10))*wtoxan(ioxide)/100.

!      CALCULATE MOLE FRACTIONS OF OXIDES
      moles=0.
      do 200 ioxide=1,10
200      moles = moles + wtoxide(ioxide)/massox(ioxide)

      do 300 ioxide=1,10
      moxide(ioxide) = wtoxide(ioxide)/massox(ioxide)
      xoxide(ioxide) = moxide(ioxide)/moles
300      continue

!      CALCULATE MOLES OF END-MEMBER COMPONENTS
      mcomp(1) = moxide(1)-0.5*(moxide(4)+moxide(5)) - moxide(6) &
         -moxide(8) - 2.*moxide(9)
      mcomp(2) = moxide(7)
      mcomp(3) = moxide(2)-moxide(9)
      mcomp(4) = moxide(3)
      mcomp(5) = 0.5*moxide(4)
      mcomp(6) = 0.5*moxide(5)
      mcomp(7) = moxide(6)
      mcomp(8) = moxide(8)
      mcomp(9) = 2.*moxide(9)
      mcomp(10) = moxide(10)

!      CALCULATE MOLE FRACTIONS (XCOMP) OF END-MEMBER COMPONENTS,
!      AVERAGE MOLECULAR WEIGHT (MWTTOT)
      moles=0.
      do 400 icomp=1,10
400      moles = moles + mcomp(icomp)

      do 500 icomp=1,10
500      xcomp(icomp) = mcomp(icomp)/moles

      mwttot = 100./moles

!      CALCULATE THERMODYNAMIC PROPERTIES OF OVERALL MELT
      cpm = 0.d00
      sumgibbs = 0.d00
      sums = 0.d00
      sumxcomp = 0.d00
      sumw = 0.d00
      sumwx = 0.d00
      sumwh = 0.d00
      sumh = 0.d00
      vtot = 0.d00
      dvmdt = 0.d00
      dvmdp = 0.d00
      do 550 icomp=1,10
550      sumwxx(icomp)=0.
      do 600 icomp=1,10
      cpm = cpm + xcomp(icomp)*cpliq(icomp)
      sumgibbs = sumgibbs + xcomp(icomp)*gapp(icomp)
      sums = sums + xcomp(icomp)*sapp(icomp)
      sumwx = sumwx + .001*w(10,icomp)*xcomp(10)*xcomp(icomp)
      sumwh = sumwh + .001*w(10,icomp)*xcomp(icomp)
      sumh = sumh + xcomp(icomp)*happ(icomp)
      vtot = vtot + xcomp(icomp)*v(icomp)
      dvmdt = dvmdt + xcomp(icomp)*dvdt(icomp)
      dvmdp = dvmdp + xcomp(icomp)*dvdp(icomp)
      if (xcomp(icomp).gt.0.) then
      sumxcomp = sumxcomp + xcomp(icomp)*log(xcomp(icomp))
      end if
      do 650 icp = 1,10
      sumw = sumw + .001*w(icomp,icp)*xcomp(icomp)*xcomp(icp)
      sumwxx(icomp) = sumwxx(icomp) + .001*w(icomp,icp)* &
             xcomp(icp)
650      continue
600      continue

      enthalpy = sumh + 0.5*sumw
      if (xcomp(10).gt.0.) then
         entropy = sums - r*sumxcomp  &
             -  r*(xcomp(10) *log(xcomp(10))  &
             + (1.-xcomp(10))*log(1.-xcomp(10)))
         swm = sapp(10) - 2.*r*log(xcomp(10))
         hwm = happ(10) + sumwxx(10) - 0.5*sumw
         gwm = gapp(10) + 2.*r*temp*log(xcomp(10)) & 
             + sumwxx(10) - 0.5*sumw
         dgdxw = (-2.*sumwxx(10) + sumw  &
             + 2.*r*temp*(1/xcomp(10) - 1.)) &
             / (1.-xcomp(10))
        else
         entropy = sums - r*sumxcomp 
      end if


!      CONVERT AVERAGE MOLECULAR WEIGHT FROM G/MOLE TO KG/MOLE
      mwttot = mwttot
      
!      CONVERT VTOT, DVMDT FROM J/(BAR MOLE K) TO M3/(KG K)
      vtot = vtot/(1.0D+05*mwttot)
      rhom = 1./vtot
      dvmdt = dvmdt/(1.0d+05*mwttot)
      dvmdp = dvmdp/(1.0d+11*mwttot)
      cpm = cpm/mwttot
      blkmag = -1/(rhom*dvmdp)

!      CONVERT ENTHALPY FROM J/MOLE TO J/KG; ENTROPY FROM J/MOLE K 
!      TO J/KG K
      enthalpy = enthalpy/mwttot
      entropy = entropy/mwttot
      hwm = hwm/0.0180152
      swm = swm/0.0180152
      gwm = gwm/0.0180152
      dgdxw = dgdxw/0.0180152

      return
      end
