        subroutine solub(pmin,pmax,tabs,wtoxan,s,beta)
        
!       PROGRAM THAT CALCULATES THERMODYNAMIC PROPERTIES OF MELTS AND STEAM
!       FOR GIVEN INPUTS OF PRESSURE, TEMPERATURE, AND CHEMICAL COMPOSITION,
!       AND CALCULATES THE SATURATION WT% WATER IN A MELT AT WHICH POINT
!       THE CHEMICAL POTENTIAL OF THE DISSOLVED WATER EQUALS THAT OF THE GAS
!       PHASE.

!       DECLARE VARIABLES

!       EXPLANATION OF VARIABLES
!       CPCONST SPECIFIC HEAT (CP) OF MAGMA AT 1 ATM PRESSURE, 0.1 WT% H2O
!       CPM     SPECIFIC HEAT (CP) OF MAGMA AT SPECIFIED PRESSURE, WT% H2O
!       TEMP    TEMPERATURE (CELSIUS)
!       TABS    TEMPERATURE (K)
!       PMIN    INITIAL PRESSURE (MPA)
!       PMAX    FINAL PRESSURE (MPA)
!       PSTPLOG LOGARITHM OF THE PRESSURE STEP
!       IPSTEPS NUMBER OF PRESSURE STEPS
!       IEX  =1 IF SATURATED MELT IS ASSUMED, =2 IF DH2O=0.1 WT% IN ALL CASES
!       S     PARAMETER USED FOR GAS SOLUBILITY (WT%/MPA)
!       BETA    PARAMTER USED FOR GAS SOLUBILITY
!       ICAL!   =1 FOR ISENTHALPIC EXPANSION, 2 FOR ISENTROPIC
!       WTOXAN(1)               WT% SIO2 (ANHYDROUS)
!       WTOXAN(2)               WT% AL2O3 (ANHYDROUS)
!       WTOXAN(2)               WT% Fe2O3 (ANHYDROUS)
!       WTOXAN(3)               WT% FeO (ANHYDROUS)
!       WTOXAN(4)               WT% MgO (ANHYDROUS)
!       WTOXAN(5)               WT% CaO (ANHYDROUS)
!       WTOXAN(6)               WT% TiO2 (ANHYDROUS)
!       WTOXAN(7)               WT% Na2O (ANHYDROUS)
!       WTOXAN(8)               WT% K2O (ANHYDROUS)
!       h2o                             MAXIMUM WT% H2O
!       DH2O                    WEIGHT FRACTION H2O DISSOLVED IN MELT

        use precis_param

        implicit none
        character*20 outfile
        real(kind=ip) :: cpH2O,cvH2O,gH2O,hH2O,sH2O,vH2O,dvdth2o
        real(kind=ip) :: blkgas,blkmag,cpm,dh2o,dgdxw,dvmdt,dxw,enthalpy, &
                entropy,gdif,gg,gwm,hg,hwm, &
                mwttot,pstep,r,rhom,sg,swm,wtoxan(9), &
                xcomp(10)
        real(kind=ip) :: beta,pbars,pmin,pmax,pres, &
                s,tabs,temp
        real(kind=ip) :: plog(50),dh2olog(50),sigma(50),sigs,sigbeta,chi2,q
        integer iox,ippstep,ipp,ippsteps

!       SET CONSTANTS, INITIALIZE VARIABLES
        r = 8.314
        ippstep = 0
        s = 0.3
        beta = 0.5
        ippsteps = 50

!       CALCULATE LOG OF PRESSURE STEP

!       pstplog = log(pmax/pmin)/(ippsteps-1)
        pstep = (pmax-pmin)/float(ippsteps-1)

        do 100 ipp=1,ippsteps
!         pres = pmin * exp(float(ipp-1)*pstplog)
          pres = pmin + float(ipp-1)*pstep
          pbars = pres*10.
          dh2o = .01*s*pres**beta
          plog(ipp) = log10(pres)

!         CALL MULTISI, HAARSI TO CALCULATE THERMO PROPS.
200       call multisi(tabs,pbars,blkmag,cpm,dh2o,enthalpy,entropy, &
                mwttot,rhom,wtoxan,xcomp,hwm,swm,gwm,dgdxw,dvmdt)

          call haarsi(tabs,pbars,cpH2O,cvH2O,gH2O,hH2O,sH2O,vH2O,blkgas, &
                dvdth2o)

          sg = sh2o/0.0180152
          hg = hh2o/0.0180152
          gg = gh2o/0.0180152
          gdif = gg-gwm

!         CHECK TO SEE IF CHEMICAL POTENTIAL OF GAS PHASE EQUALS
!         THAT OF DISSOLVED WATER.  IF NOT, ADJUST AMOUNT OF DISSOLVED
!         WATER UNTIL THEY AGREE

          if (abs(gdif/gg).gt.1.0e-05) then
            dxw = gdif/dgdxw
            dh2o = dh2o + dh2o/xcomp(10)*dxw
            if (dh2o.lt.0.) dh2o = 0.0001
            go to 200
          end if

          dh2olog(ipp) = log10(dh2o)
100     continue

!       ASSUME (SOMEWHAT ARBITRARILY) THAT THE UNCERTAINTY IN DH2O
!       IS ABOUT 0.2 WT% FOR EACH DATA POINT
        do 150 ipp=1,ippsteps
150     sigma(ipp) = 2.d-03

!       CALL SUBROUTINE THAT CALCULATES S AND BETA
        call fit(plog,dh2olog,50,sigma,0_8,s,beta,sigs,sigbeta,chi2,q)

        s = 100.*(10.**s)

        return
        end

      FUNCTION gammq(a,x)
      REAL*8 a,gammq,x
!U    USES gcf,gser
      REAL*8 gammcf,gamser,gln
      if(x.lt.0..or.a.le.0.) then
            write (6,*) 'bad arguments in gammq'
            stop
      end if
      if(x.lt.a+1.)then
        call gser(gamser,a,x,gln)
        gammq=1.-gamser
      else
        call gcf(gammcf,a,x,gln)
        gammq=gammcf
      endif
      return
      END

      FUNCTION gammln(xx)
      REAL*8 gammln,xx
      INTEGER j
      DOUBLE PRECISION ser,stp,tmp,x,y,cof(6)
      SAVE cof,stp
      DATA cof,stp/76.18009172947146d0,-86.50532032941677d0, &
      24.01409824083091d0,-1.231739572450155d0,.1208650973866179d-2, &
      -.5395239384953d-5,2.5066282746310005d0/
      x=xx
      y=x
      tmp=x+5.5d0
      tmp=(x+0.5d0)*log(tmp)-tmp
      ser=1.000000000190015d0
      do 11 j=1,6
        y=y+1.d0
        ser=ser+cof(j)/y
11    continue
      gammln=tmp+log(stp*ser/x)
      return
      END
